import { Address, Hash } from 'viem';

declare enum ProductType {
    Unknown = 0,
    Perpetual = 1,
    Spot = 2
}
declare const buildAccountId: (address: Address, productType: ProductType, brokerId: number, subaccountIndex: number) => Hash;
type Side = 'ask' | 'bid';
declare const TIME_IN_FORCES: readonly ["default", "immediate_or_cancel", "fill_or_kill", "post_only"];
declare const SELF_TRADE_BEHAVIORS: readonly ["cancel_provide", "decrease_take", "expire_both", "fill"];
type TimeInForce = (typeof TIME_IN_FORCES)[number];
type SeltTradeBehavior = (typeof SELF_TRADE_BEHAVIORS)[number];
type OrderFlag = {
    timeInForce: TimeInForce;
    selfTradeBehavior: SeltTradeBehavior;
    reduceOnly: boolean;
    expiresAt: number | undefined | null;
    isMarketOrder: boolean;
};
declare const DEFAULT_ORDER_FLAG: OrderFlag;
declare const encodeFlag: (flag: OrderFlag) => bigint;
declare const EIP712_DOMAIN: {
    readonly name: "FOUNDATION";
    readonly chainId: 1;
    readonly version: "0.1.0";
};
type NumericString = `${number}`;
type OrderStatus = 'placed' | 'filled' | 'partial_filled' | 'canceled' | 'conditional_canceled';

export { DEFAULT_ORDER_FLAG, EIP712_DOMAIN, type NumericString, type OrderFlag, type OrderStatus, ProductType, type SeltTradeBehavior, type Side, type TimeInForce, buildAccountId, encodeFlag };
